@@ -1,23 +1,39 @@
-from .base import IAliasProvider, IPlayerProvider, ISongProvider, IScoreProvider, ICurveProvider, IRegionProvider, IItemListProvider
-from .divingfish import DivingFishProvider
-from .lxns import LXNSProvider
-from .yuzu import YuzuProvider
-from .wechat import WechatProvider
 from .arcade import ArcadeProvider
+from .base import (
+    IAliasProvider,
+    IAreaProvider,
+    ICurveProvider,
+    IItemListProvider,
+    IPlayerIdentifierProvider,
+    IPlayerProvider,
+    IProvider,
+    IRegionProvider,
+    IScoreProvider,
+    IScoreUpdateProvider,
+    ISongProvider,
+)
+from .divingfish import DivingFishProvider
 from .local import LocalProvider
+from .lxns import LXNSProvider
+from .wechat import WechatProvider
+from .yuzu import YuzuProvider
 
 __all__ = [
+    "IProvider",
+    "IScoreUpdateProvider",
     "IAliasProvider",
-    "IPlayerProvider",
-    "ISongProvider",
-    "IScoreProvider",
+    "IAreaProvider",
     "ICurveProvider",
     "IItemListProvider",
+    "IPlayerProvider",
     "IRegionProvider",
-    "LocalProvider",
-    "DivingFishProvider",
-    "LXNSProvider",
-    "YuzuProvider",
-    "WechatProvider",
+    "IScoreProvider",
+    "ISongProvider",
+    "IPlayerIdentifierProvider",
     "ArcadeProvider",
+    "DivingFishProvider",
+    "LocalProvider",
+    "LXNSProvider",
+    "WechatProvider",
+    "YuzuProvider",
 ]
