@@ -15,7 +15,7 @@ SCORE_COEFFICIENT_TABLE = [
     [80, 13.6, "a"],
     [90, 15.2, "aa"],
     [94, 16.8, "aaa"],
-    [96.9999, 17.6, "s"],
+    [96.9999, 17.6, "aaa"],
     [97, 20.0, "s"],
     [98, 20.3, "sp"],
     [98.9999, 20.6, "sp"],
